ZhNativeChannelPlugin class

Flutter Web 插件注册入口。

Flutter 的 plugin 配置要求 Web 入口文件提供 registerWith 静态方法; 实际处理逻辑放在 ZHNativeChannelWebPlugin 中。

Constructors

ZhNativeChannelPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
注册 Web 插件。